/**
 * 内部错误码
 */
export declare enum InnerErrorCode {
    /** 请求出错 */
    REQUEST_ERROR = "REQUEST_ERROR",
    /** 未响应 */
    NO_RESPONSE = "NO_RESPONSE",
    /** 超时未响应 */
    NO_RESPONSE_TIMEOUT = "NO_RESPONSE_TIMEOUT",
    /** 离线未响应 */
    NO_RESPONSE_OFFLINE = "NO_RESPONSE_OFFLINE",
    /** 分发响应结果执行出错 */
    DISPATCH_RESPONSE = "DISPATCH_RESPONSE",
    /** 处理RequestFailResult错误时出错 */
    DEAL_ERROR = "DEAL_ERROR",
    /** 无业务码 */
    NO_BUSINESS_CODE = "NO_BUSINESS_CODE",
    /** 无网络错误码 */
    NO_NETWORK_CODE = "NO_NETWORK_CODE",
    /**
     * 请求被中止
     */
    ABORT = "ABORT"
}
interface ErrorOptions {
    code: number | InnerErrorCode;
    message: string;
    isBusinessError: boolean;
}
/**
 * 请求失败信息
 */
export declare class RequestFailResultBase extends Error {
    /** 错误码 */
    code: ErrorOptions["code"];
    /** 是否业务错误 */
    isBusinessError: boolean;
    /** 错误信息 */
    message: string;
    constructor({ message, code, isBusinessError }: ErrorOptions);
}
/**
 * 网络错误
 */
export declare class RequestFailResultNetwork extends RequestFailResultBase {
    cause: unknown;
    /**
     * @param cause 错误原因
     */
    constructor({ message, code, cause, }: Omit<ErrorOptions, "isBusinessError"> & {
        /** 错误原因 */
        cause?: unknown;
    });
}
/**
 * 业务错误
 */
export declare class RequestFailResultBusiness extends RequestFailResultBase {
    constructor({ message, code }: Omit<ErrorOptions, "isBusinessError">);
}
/**
 * 请求失败结果
 */
export type RequestFailResult = Pick<RequestFailResultNetwork, keyof ErrorOptions | "cause"> | Pick<RequestFailResultBusiness, keyof ErrorOptions>;
export {};
